==> nextcloud-23.0.3.tgz: nextcloud/apps/theming/l10n/sk.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Načítavanie ukážky...",
    "Saved" : "Uložené",
    "Admin" : "Správca",
    "a safe home for all your data" : "bezpečný domov pre všetky vaše dáta",
    "Name cannot be empty" : "Názov nemôže byť prázdny",
    "The given name is too long" : "Zadané meno je príliš dlhé",
    "The given web address is too long" : "Zadaná web adresa je príliš dlhá",
    "The given web address is not a valid URL" : "Zadaná web adresa nie je platná adresa URL",
    "The given legal notice address is too long" : "Zadaná adresa právneho upozornenia je príliš dlhá",
    "The given legal notice address is not a valid URL" : "Zadaná adresa právneho upozornenia nie je platná adresa URL",
    "The given privacy policy address is too long" : "Zadaná adresa zásady ochrany osobných údajov je príliš dlhá",
    "The given privacy policy address is not a valid URL" : "Zadaná adresa zásady ochrany osobných údajov nie je platná adresa URL",
    "The given slogan is too long" : "Zadaný slogan je príliš dlhý",
    "The given color is invalid" : "Zadaná farba nie je platná",
    "The file was uploaded" : "Súbor bol nahraný",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Nahraný súbor prekročil limit nastavený v upload_max_filesize v súbore php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ukladaný súbor prekračuje nastavenie MAX_FILE_SIZE z volieb HTML formulára.",
    "The file was only partially uploaded" : "Súbor sa nahral len čiastočne",
    "No file was uploaded" : "Nenahral sa žiadny súbor",
    "Missing a temporary folder" : "Chýba priečinok pre dočasné súbory",
    "Could not write file to disk" : "Nepodarilo sa zapísať súbor na disk.",
    "A PHP extension stopped the file upload" : "rozšírenie PHP zastavilo nahrávanie súboru.",
    "No file uploaded" : "Žiadny súbor nebol nahraný",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Už používate vlastný motív vzhľadu. Predošlé nastavenia tým môžu byť prepísané.",
    "Theming" : "Zmena vzhľadu",
    "Legal notice" : "Právne upozornenie",
    "Privacy policy" : "Zásady ochrany osobných údajov",
    "Adjust the Nextcloud theme" : "Upraviť motív vzhľadu Nextcloudu",
    "Open documentation" : "Otvoriť dokumentáciu",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Zmena vzhľadu umožňuje ľahko upraviť pocit z vašej inštalácie a podporovaných klientov. Toto bude viditeľné pre všetkých klientov.",
    "Name" : "Názov",
    "Reset to default" : "Nastaviť predvolené",
    "Web link" : "Webový odkaz",
    "https://…" : "https://...",
    "Slogan" : "Slogan",
    "Color" : "Farba",
    "Logo" : "Logo",
    "Upload new logo" : "Nahrať nové logo",
    "Login image" : "Prihlasovací obrázok",
    "Upload new login background" : "Nahrať nové prihlasovacie pozadie",
    "Remove background image" : "Odstrániť obrázok pozadia",
    "Advanced options" : "Pokročilé možnosti",
    "Legal notice link" : "Odkaz na právne upozornenie",
    "Privacy policy link" : "Odkaz na zásady ochrany osobných údajov",
    "Header logo" : "Logo v hlavičke",
    "Upload new header logo" : "Nahrať nové logo do hlavičky",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Nahrať novú ikonu webu",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Ak chcete automaticky generovať favikony na základe nahraného loga a farby, nainštalujte rozšírenie Imagemagick PHP s podporou pre SVG obrázky."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-23.0.5.tgz: nextcloud/apps/theming/l10n/sk.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Načítavanie ukážky...",
    "Admin" : "Správca",
    "Saved" : "Uložené",
    "a safe home for all your data" : "bezpečný domov pre všetky vaše dáta",
    "Name cannot be empty" : "Názov nemôže byť prázdny",
    "The given name is too long" : "Zadané meno je príliš dlhé",
    "The given web address is too long" : "Zadaná web adresa je príliš dlhá",
    "The given web address is not a valid URL" : "Zadaná web adresa nie je platná adresa URL",
    "The given legal notice address is too long" : "Zadaná adresa právneho upozornenia je príliš dlhá",
    "The given legal notice address is not a valid URL" : "Zadaná adresa právneho upozornenia nie je platná adresa URL",
    "The given privacy policy address is too long" : "Zadaná adresa zásady ochrany osobných údajov je príliš dlhá",
    "The given privacy policy address is not a valid URL" : "Zadaná adresa zásady ochrany osobných údajov nie je platná adresa URL",
    "The given slogan is too long" : "Zadaný slogan je príliš dlhý",
    "The given color is invalid" : "Zadaná farba nie je platná",
    "The file was uploaded" : "Súbor bol nahraný",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Nahraný súbor prekročil limit nastavený v upload_max_filesize v súbore php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ukladaný súbor prekračuje nastavenie MAX_FILE_SIZE z volieb HTML formulára.",
    "The file was only partially uploaded" : "Súbor sa nahral len čiastočne",
    "No file was uploaded" : "Nenahral sa žiadny súbor",
    "Missing a temporary folder" : "Chýba priečinok pre dočasné súbory",
    "Could not write file to disk" : "Nepodarilo sa zapísať súbor na disk.",
    "A PHP extension stopped the file upload" : "rozšírenie PHP zastavilo nahrávanie súboru.",
    "No file uploaded" : "Žiadny súbor nebol nahraný",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Už používate vlastný motív vzhľadu. Predošlé nastavenia tým môžu byť prepísané.",
    "Theming" : "Zmena vzhľadu",
    "Appearance and accessibility" : "Vzhľad a správanie",
    "Dark theme with high contrast mode" : "Tmavá téma s vysokým kontrastom",
    "Enable dark high contrast mode" : "Zapnúť režim vysokého kontrastu",
    "Dark theme" : "Tmavý motív vzhľadu",
    "Enable dark theme" : "Zapnúť tmavý motív vzhľadu",
    "System default theme" : "Predvolený vzhľad systému",
    "Enable the system default" : "Povoliť systémové nastavenia",
    "Dyslexia font" : "Písmo pre dyslektikov",
    "Enable dyslexia font" : "Povoliť písmo pre dyslektikov",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic je slobodný typ písma navrhnutý priamo pre obmedzenie vplyvu niektorých bežných porúch čítania spôsobených dyslexiou.",
    "High contrast mode" : "Režim vysokého kontrastu",
    "Enable high contrast mode" : "Zapnúť režim vysokého kontrastu",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Mód s vysokým kontrastom pre uľahčenie navigácie. Zníži sa síce vizuálna kvalita, ale zvýši sa čitateľnosť.",
    "Legal notice" : "Právne upozornenie",
    "Privacy policy" : "Zásady ochrany osobných údajov",
    "Adjust the Nextcloud theme" : "Upraviť motív vzhľadu Nextcloudu",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Univerzálny prístup je pre nás veľmi dôležitý. Dodržiavame webové štandardy a kontrolujeme, aby bolo všetko použiteľné aj bez myši a pomocného softvéru, ako sú čítačky obrazovky. Naším cieľom je byť v súlade s {guidelines}pokynmi pre prístup k webovému obsahu {linkend} 2.1 na úrovni AA,  v režime vysokého kontrastu dokonca na úrovni AAA.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Ak nájdete nejaký problém, neváhajte a nahláste ho na {issuetracker}nástroj na sledovanie problémov{linkend}. A ak sa chcete zapojiť, pripojte sa k {designteam}nášmu dizajnérskemu tímu{linkend}!",
    "Open documentation" : "Otvoriť dokumentáciu",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Zmena vzhľadu umožňuje ľahko upraviť pocit z vašej inštalácie a podporovaných klientov. Toto bude viditeľné pre všetkých klientov.",
    "Name" : "Názov",
    "Reset to default" : "Nastaviť predvolené",
    "Web link" : "Webový odkaz",
    "https://…" : "https://...",
    "Slogan" : "Slogan",
    "Color" : "Farba",
    "Logo" : "Logo",
    "Upload new logo" : "Nahrať nové logo",
    "Login image" : "Prihlasovací obrázok",
    "Upload new login background" : "Nahrať nové prihlasovacie pozadie",
    "Remove background image" : "Odstrániť obrázok pozadia",
    "Advanced options" : "Pokročilé možnosti",
    "Legal notice link" : "Odkaz na právne upozornenie",
    "Privacy policy link" : "Odkaz na zásady ochrany osobných údajov",
    "Header logo" : "Logo v hlavičke",
    "Upload new header logo" : "Nahrať nové logo do hlavičky",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Nahrať novú ikonu webu",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Ak chcete automaticky generovať favikony na základe nahraného loga a farby, nainštalujte rozšírenie Imagemagick PHP s podporou pre SVG obrázky."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
